@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-08 by the Quassel Project                          *
+ *   Copyright (C) 2005-2019 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,31 +15,51 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include "clientbufferviewmanager.h"
 
 #include "clientbufferviewconfig.h"
+#include "client.h"
+#include "networkmodel.h"
 
 INIT_SYNCABLE_OBJECT(ClientBufferViewManager)
 ClientBufferViewManager::ClientBufferViewManager(SignalProxy *proxy, QObject *parent)
-  : BufferViewManager(proxy, parent)
+    : BufferViewManager(proxy, parent)
 {
 }
 
-BufferViewConfig *ClientBufferViewManager::bufferViewConfigFactory(int bufferViewConfigId) {
-  return new ClientBufferViewConfig(bufferViewConfigId, this);
+
+BufferViewConfig *ClientBufferViewManager::bufferViewConfigFactory(int bufferViewConfigId)
+{
+    return new ClientBufferViewConfig(bufferViewConfigId, this);
 }
 
-QList<ClientBufferViewConfig *> ClientBufferViewManager::clientBufferViewConfigs() const {
-  QList<ClientBufferViewConfig *> clientConfigs;
-  foreach(BufferViewConfig *config, bufferViewConfigs()) {
-    clientConfigs << static_cast<ClientBufferViewConfig *>(config);
-  }
-  return clientConfigs;
+
+QList<ClientBufferViewConfig *> ClientBufferViewManager::clientBufferViewConfigs() const
+{
+    QList<ClientBufferViewConfig *> clientConfigs;
+    foreach(BufferViewConfig *config, bufferViewConfigs()) {
+        clientConfigs << static_cast<ClientBufferViewConfig *>(config);
+    }
+    return clientConfigs;
 }
 
-ClientBufferViewConfig *ClientBufferViewManager::clientBufferViewConfig(int bufferViewId) const {
-  return static_cast<ClientBufferViewConfig *>(bufferViewConfig(bufferViewId));
+
+ClientBufferViewConfig *ClientBufferViewManager::clientBufferViewConfig(int bufferViewId) const
+{
+    return static_cast<ClientBufferViewConfig *>(bufferViewConfig(bufferViewId));
+}
+
+
+void ClientBufferViewManager::setInitialized()
+{
+    if (bufferViewConfigs().isEmpty()) {
+        BufferViewConfig config(-1);
+        config.setBufferViewName(tr("All Chats"));
+        config.initSetBufferList(Client::networkModel()->allBufferIdsSorted());
+        requestCreateBufferView(config.toVariantMap());
+    }
+    BufferViewManager::setInitialized();
 }
