@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-09 by the Quassel Project                          *
+ *   Copyright (C) 2005-2019 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef CLIENTIRCLISTHELPER_H
@@ -23,24 +23,30 @@
 
 #include "irclisthelper.h"
 
-class ClientIrcListHelper : public IrcListHelper {
-  Q_OBJECT
+class ClientIrcListHelper : public IrcListHelper
+{
+    SYNCABLE_OBJECT
+        Q_OBJECT
 
 public:
-  inline ClientIrcListHelper(QObject *object = 0) : IrcListHelper(object) {};
+    inline ClientIrcListHelper(QObject *object = 0) : IrcListHelper(object) {};
 
-  inline virtual const QMetaObject *syncMetaObject() const { return &IrcListHelper::staticMetaObject; }
+    inline virtual const QMetaObject *syncMetaObject() const { return &IrcListHelper::staticMetaObject; }
 
 public slots:
-  virtual QVariantList requestChannelList(const NetworkId &netId, const QStringList &channelFilters);
-  virtual void receiveChannelList(const NetworkId &netId, const QStringList &channelFilters, const QVariantList &channels);
-  virtual void reportFinishedList(const NetworkId &netId);
+    virtual QVariantList requestChannelList(const NetworkId &netId, const QStringList &channelFilters);
+    virtual void receiveChannelList(const NetworkId &netId, const QStringList &channelFilters, const QVariantList &channels);
+    virtual void reportFinishedList(const NetworkId &netId);
+    inline virtual void reportError(const QString &error) { emit errorReported(error); }
 
 signals:
-  void channelListReceived(const NetworkId &netId, const QStringList &channelFilters, const QList<IrcListHelper::ChannelDescription> &channelList);
+    void channelListReceived(const NetworkId &netId, const QStringList &channelFilters, const QList<IrcListHelper::ChannelDescription> &channelList);
+    void finishedListReported(const NetworkId &netId);
+    void errorReported(const QString &error);
 
 private:
-  NetworkId _netId;
+    NetworkId _netId;
 };
 
+
 #endif //CLIENTIRCLISTHELPER_H
