@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-09 by the Quassel Project                          *
+ *   Copyright (C) 2005-2019 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef BACKLOGMANAGER_H
@@ -24,23 +24,30 @@
 #include "syncableobject.h"
 #include "types.h"
 
-class BacklogManager : public SyncableObject {
-  Q_OBJECT
+class BacklogManager : public SyncableObject
+{
+    SYNCABLE_OBJECT
+        Q_OBJECT
 
 public:
-  BacklogManager(QObject *parent = 0) : SyncableObject(parent) {}
-  inline virtual const QMetaObject *syncMetaObject() const { return &staticMetaObject; }
+    BacklogManager(QObject *parent = 0) : SyncableObject(parent) {}
+    inline virtual const QMetaObject *syncMetaObject() const { return &staticMetaObject; }
 
 public slots:
-  virtual QVariantList requestBacklog(BufferId bufferId, MsgId first = -1, MsgId last = -1, int limit = -1, int additional = 0);
-  inline virtual void receiveBacklog(BufferId, MsgId, MsgId, int, int, QVariantList) {};
+    virtual QVariantList requestBacklog(BufferId bufferId, MsgId first = -1, MsgId last = -1, int limit = -1, int additional = 0);
+    virtual QVariantList requestBacklogFiltered(BufferId bufferId, MsgId first = -1, MsgId last = -1, int limit = -1, int additional = 0, int type = -1, int flags = -1);
+    inline virtual void receiveBacklog(BufferId, MsgId, MsgId, int, int, QVariantList) {};
+    inline virtual void receiveBacklogFiltered(BufferId, MsgId, MsgId, int, int, int, int, QVariantList) {};
 
-  virtual QVariantList requestBacklogAll(MsgId first = -1, MsgId last = -1, int limit = -1, int additional = 0);
-  inline virtual void receiveBacklogAll(MsgId, MsgId, int, int, QVariantList) {};
+    virtual QVariantList requestBacklogAll(MsgId first = -1, MsgId last = -1, int limit = -1, int additional = 0);
+    virtual QVariantList requestBacklogAllFiltered(MsgId first = -1, MsgId last = -1, int limit = -1, int additional = 0, int type = -1, int flags = -1);
+    inline virtual void receiveBacklogAll(MsgId, MsgId, int, int, QVariantList) {};
+    inline virtual void receiveBacklogAllFiltered(MsgId, MsgId, int, int, int, int, QVariantList) {};
 
 signals:
-  void backlogRequested(BufferId, MsgId, MsgId, int, int);
-  void backlogAllRequested(MsgId, MsgId, int, int);
+    void backlogRequested(BufferId, MsgId, MsgId, int, int);
+    void backlogAllRequested(MsgId, MsgId, int, int);
 };
 
+
 #endif // BACKLOGMANAGER_H
