@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-09 by the Quassel Project                          *
+ *   Copyright (C) 2005-2019 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef COREALIASMANAGER_H
@@ -25,18 +25,25 @@
 
 class CoreSession;
 
-class CoreAliasManager : public AliasManager {
-  Q_OBJECT
+class CoreAliasManager : public AliasManager
+{
+    SYNCABLE_OBJECT
+        Q_OBJECT
 
 public:
-  CoreAliasManager(CoreSession *parent = 0);
-  ~CoreAliasManager();
+    explicit CoreAliasManager(CoreSession *parent);
 
-  inline virtual const QMetaObject *syncMetaObject() const { return &AliasManager::staticMetaObject; }
+    inline virtual const QMetaObject *syncMetaObject() const { return &AliasManager::staticMetaObject; }
+
+protected:
+    const Network *network(NetworkId) const;
+
+private slots:
+    void save() const;
 
 private:
-  void loadDefaults();
-  
+    void loadDefaults();
 };
 
+
 #endif //COREALIASMANAGER_H
