@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-09 by the Quassel Project                          *
+ *   Copyright (C) 2005-2019 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef COREBUFFERVIEWMANAGER_H
@@ -25,25 +25,27 @@
 
 class CoreSession;
 
-class CoreBufferViewManager : public BufferViewManager {
-  Q_OBJECT
+class CoreBufferViewManager : public BufferViewManager
+{
+    SYNCABLE_OBJECT
+        Q_OBJECT
 
 public:
-  CoreBufferViewManager(SignalProxy *proxy, CoreSession *parent);
-  
-  inline virtual const QMetaObject *syncMetaObject() const { return &BufferViewManager::staticMetaObject; }
+    CoreBufferViewManager(SignalProxy *proxy, CoreSession *parent);
+
+    inline virtual const QMetaObject *syncMetaObject() const { return &BufferViewManager::staticMetaObject; }
 
 public slots:
-  virtual void requestCreateBufferView(const QVariantMap &properties);
-  virtual void requestCreateBufferViews(const QVariantList &properties);
-  virtual void requestDeleteBufferView(int bufferViewId);
-  virtual void requestDeleteBufferViews(const QVariantList &bufferViews);
+    virtual void requestCreateBufferView(const QVariantMap &properties);
+    virtual void requestCreateBufferViews(const QVariantList &properties);
+    virtual void requestDeleteBufferView(int bufferViewId);
+    virtual void requestDeleteBufferViews(const QVariantList &bufferViews);
 
-  void saveBufferViews();
+    void saveBufferViews();
 
 private:
-  CoreSession *_coreSession;
+    CoreSession *_coreSession;
 };
 
-#endif // COREBUFFERVIEWMANAGER_H
 
+#endif // COREBUFFERVIEWMANAGER_H
