@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-09 by the Quassel Project                          *
+ *   Copyright (C) 2005-2019 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,48 +15,52 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef SETTINGSDLG_H
 #define SETTINGSDLG_H
 
-#include <QtGui>
+#include <QDialog>
+
 #include "ui_settingsdlg.h"
 
 #include "settingspage.h"
 
-class SettingsDlg : public QDialog {
-  Q_OBJECT
+class SettingsDlg : public QDialog
+{
+    Q_OBJECT
 
 public:
-  SettingsDlg(QWidget *parent = 0);
-  void registerSettingsPage(SettingsPage *);
-  void unregisterSettingsPage(SettingsPage *);
+    SettingsDlg(QWidget *parent = 0);
+    void registerSettingsPage(SettingsPage *);
+    void unregisterSettingsPage(SettingsPage *);
 
-  inline SettingsPage *currentPage() const { return _currentPage; }
+    inline SettingsPage *currentPage() const { return _currentPage; }
 
 public slots:
-  void selectPage(SettingsPage *sp); // const QString &category, const QString &title);
+    void selectPage(SettingsPage *sp); // const QString &category, const QString &title);
 
 private slots:
-  void itemSelected();
-  void buttonClicked(QAbstractButton *);
-  bool applyChanges();
-  void undoChanges();
-  void reload();
-  void loadDefaults();
-  void setButtonStates();
-  
-private:
-  Ui::SettingsDlg ui;
-  
-  SettingsPage *_currentPage;
-  QHash<SettingsPage *, bool> pageIsLoaded;
+    void coreConnectionStateChanged();
+    void itemSelected();
+    void buttonClicked(QAbstractButton *);
+    bool applyChanges();
+    void undoChanges();
+    void reload();
+    void loadDefaults();
+    void setButtonStates();
+    void setItemState(QTreeWidgetItem *);
 
-  enum {
-    SettingsPageRole = Qt::UserRole
-  };
+private:
+    Ui::SettingsDlg ui;
+
+    SettingsPage *_currentPage;
+    QHash<SettingsPage *, bool> pageIsLoaded;
+
+    enum {
+        SettingsPageRole = Qt::UserRole
+    };
 };
 
 
