@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-09 by the Quassel Project                          *
+ *   Copyright (C) 2005-2019 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,25 +15,27 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef SETTINGSPAGEDLG_H
 #define SETTINGSPAGEDLG_H
 
-#include <QtGui>
+#include <QDialog>
+
 #include "ui_settingspagedlg.h"
 
 #include "settingspage.h"
 
-class SettingsPageDlg : public QDialog {
-  Q_OBJECT
-  public:
-    SettingsPageDlg(SettingsPage * page, QWidget *parent = 0);
+class SettingsPageDlg : public QDialog
+{
+    Q_OBJECT
+public:
+    SettingsPageDlg(SettingsPage *page, QWidget *parent = 0);
 
     SettingsPage *currentPage() const;
 
-  private slots:
+private slots:
     void buttonClicked(QAbstractButton *);
     bool applyChanges();
     void undoChanges();
@@ -41,11 +43,11 @@ class SettingsPageDlg : public QDialog {
     void loadDefaults();
     void setButtonStates();
 
-  private:
+private:
     Ui::SettingsPageDlg ui;
 
     SettingsPage *_currentPage;
-
 };
 
+
 #endif
