@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-09 by the Quassel Project                          *
+ *   Copyright (C) 2005-2019 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,35 +15,50 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include "titlesetter.h"
 
 #include "abstractitemview.h"
+#include "client.h"
 #include "mainwin.h"
 
 TitleSetter::TitleSetter(MainWin *parent)
-  : AbstractItemView(parent),
+    : AbstractItemView(parent),
     _mainWin(parent)
 {
-
 }
 
-void TitleSetter::currentChanged(const QModelIndex &current, const QModelIndex &previous) {
-  Q_UNUSED(previous);
-  changeWindowTitle(current.sibling(current.row(), 0).data().toString());
+
+void TitleSetter::currentChanged(const QModelIndex &current, const QModelIndex &previous)
+{
+    Q_UNUSED(previous);
+    changeWindowTitle(current.sibling(current.row(), 0));
 }
 
-void TitleSetter::dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight) {
-  QItemSelectionRange changedArea(topLeft, bottomRight);
-  QModelIndex currentTopicIndex = selectionModel()->currentIndex().sibling(selectionModel()->currentIndex().row(), 0);
-  if(changedArea.contains(currentTopicIndex))
-    changeWindowTitle(currentTopicIndex.data().toString());
+
+void TitleSetter::dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight)
+{
+    QItemSelectionRange changedArea(topLeft, bottomRight);
+    QModelIndex currentTopicIndex = selectionModel()->currentIndex().sibling(selectionModel()->currentIndex().row(), 0);
+    if (changedArea.contains(currentTopicIndex))
+        changeWindowTitle(currentTopicIndex);
 };
 
-void TitleSetter::changeWindowTitle(QString title) {
-  QString newTitle = QString("%1 - %2").arg("Quassel IRC").arg(title);
-  _mainWin->setWindowTitle(newTitle);
-  _mainWin->setWindowIconText(newTitle);
+void TitleSetter::changeWindowTitle(const QModelIndex &index)
+{
+    BufferId id = index.data(NetworkModel::BufferIdRole).value<BufferId>();
+    if (!id.isValid())
+        return;
+
+    QString title;
+    if (Client::networkModel()->bufferType(id) == BufferInfo::StatusBuffer)
+        title = index.data().toString();
+    else
+        title = QString("%1 (%2)").arg(index.data().toString(), Client::networkModel()->networkName(id));
+    QString newTitle = QString("%1 - %2").arg("Quassel IRC").arg(title);
+
+    _mainWin->setWindowTitle(newTitle);
+    _mainWin->setWindowIconText(newTitle);
 }
