@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005/06 by the Quassel Project                          *
+ *   Copyright (C) 2005-2019 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef TOPICWIDGET_H_
@@ -25,35 +25,45 @@
 
 #include "ui_topicwidget.h"
 
-class TopicWidget : public AbstractItemView {
-  Q_OBJECT
+class TopicWidget : public AbstractItemView
+{
+    Q_OBJECT
 
 public:
-  TopicWidget(QWidget *parent = 0);
+    TopicWidget(QWidget *parent = 0);
 
-  void setTopic(const QString &newtopic);
-  void setCustomFont(const QFont &);
+    void setTopic(const QModelIndex &index);
+    void setCustomFont(const QFont &);
+    void setReadOnly(const bool &readonly);
 
-  virtual bool eventFilter(QObject *obj, QEvent *event);
+    virtual bool eventFilter(QObject *obj, QEvent *event);
+    inline bool isReadOnly() const { return _readonly; }
+
+signals:
+    void switchedPlain();
 
 protected slots:
-  virtual void currentChanged(const QModelIndex &current, const QModelIndex &previous);
-  virtual void dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
+    virtual void currentChanged(const QModelIndex &current, const QModelIndex &previous);
+    virtual void dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
 
 private slots:
-  void on_topicLineEdit_textEntered();
-  void on_topicEditButton_clicked();
-  void switchEditable();
-  void switchPlain();
-  void clickableActivated(const Clickable &);
-  void updateResizeMode();
-  void setCustomFont(const QVariant &);
-  void setUseCustomFont(const QVariant &);
+    void on_topicLineEdit_textEntered();
+    void on_topicEditButton_clicked();
+    void switchEditable();
+    void switchPlain();
+    void clickableActivated(const Clickable &);
+    void updateResizeMode();
+    void setCustomFont(const QVariant &);
+    void setUseCustomFont(const QVariant &);
 
 private:
-  Ui::TopicWidget ui;
+    QString sanitizeTopic(const QString& topic);
 
-  QString _topic;
+    Ui::TopicWidget ui;
+
+    QString _topic;
+    bool _mouseEntered;
+    bool _readonly;
 };
 
 
