@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-09 by the Quassel Project                          *
+ *   Copyright (C) 2005-2019 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include "colorbutton.h"
@@ -24,46 +24,46 @@
 #include <QStyle>
 #include <QStyleOptionFrame>
 
-ColorButton::ColorButton(QWidget *parent) : QPushButton(parent) {
+#ifdef HAVE_KDE4
+#  include <KColorDialog>
+#else
+#  include <QColorDialog>
+#endif
 
+ColorButton::ColorButton(QWidget *parent) : QToolButton(parent)
+{
+    setText("");
+    connect(this, SIGNAL(clicked()), SLOT(chooseColor()));
 }
 
-void ColorButton::setColor(const QColor &color) {
-  _color = color;
-  update();
+
+void ColorButton::setColor(const QColor &color)
+{
+    _color = color;
+    QPixmap pixmap(QSize(32, 32));
+    pixmap.fill(color);
+    setIcon(pixmap);
+
+    emit colorChanged(color);
 }
 
-QColor ColorButton::color() const {
-  return _color;
+
+QColor ColorButton::color() const
+{
+    return _color;
 }
 
-/* This has been heavily inspired by KDE's KColorButton, thanks! */
-void ColorButton::paintEvent(QPaintEvent *) {
-  QPainter painter(this);
 
-  QStyleOptionButton opt;
-  initStyleOption(&opt);
-  opt.state |= isDown() ? QStyle::State_Sunken : QStyle::State_Raised;
-  opt.features = QStyleOptionButton::None;
-  if(isDefault())
-    opt.features |= QStyleOptionButton::DefaultButton;
+void ColorButton::chooseColor()
+{
+#ifdef HAVE_KDE4
+    QColor c = color();
+    KColorDialog::getColor(c, this);
+#else
+    QColor c = QColorDialog::getColor(color(), this);
+#endif
 
-  // Draw bevel
-  style()->drawControl(QStyle::CE_PushButtonBevel, &opt, &painter, this);
-
-  // Calc geometry
-  QRect labelRect = style()->subElementRect(QStyle::SE_PushButtonContents, &opt, this);
-  int shift = style()->pixelMetric(QStyle::PM_ButtonMargin);
-  labelRect.adjust(shift, shift, -shift, -shift);
-  int x, y, w, h;
-  labelRect.getRect(&x, &y, &w, &h);
-
-  if(isChecked() || isDown()) {
-    x += style()->pixelMetric(QStyle::PM_ButtonShiftHorizontal);
-    y += style()->pixelMetric(QStyle::PM_ButtonShiftVertical);
-  }
-
-  // Draw color rect
-  QBrush brush = isEnabled() ? color() : palette().color(backgroundRole());
-  qDrawShadePanel(&painter, x, y, w, h, palette(), true, 1, &brush);
+    if (c.isValid()) {
+        setColor(c);
+    }
 }
