@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-09 by the Quassel Project                          *
+ *   Copyright (C) 2005-2019 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,30 +15,38 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef COLORBUTTON_H_
 #define COLORBUTTON_H_
 
-#include <QPushButton>
+#include <QToolButton>
 
-class ColorButton : public QPushButton {
-  Q_OBJECT
-  Q_PROPERTY(QColor color READ color WRITE setColor USER true)
+class ColorButton : public QToolButton
+{
+    Q_OBJECT
+    Q_PROPERTY(QColor color READ color WRITE setColor USER true)
 
-  public:
-    explicit ColorButton(QWidget *parent = 0);
+public :
+        explicit ColorButton(QWidget *parent = 0);
     explicit ColorButton(const QColor &c, QWidget *parent = 0);
 
     void setColor(const QColor &color);
     QColor color() const;
 
-  protected:
-    void paintEvent(QPaintEvent *event);
+signals:
+    void colorChanged(const QColor &);
 
-  private:
+protected:
+    //void paintEvent(QPaintEvent *event);
+
+private slots:
+    void chooseColor();
+
+private:
     QColor _color;
 };
 
+
 #endif
